@@ -6,7 +6,7 @@ use utf8;
 use Carp;
 ## no critic (RequireCarping)
 
-our $VERSION = 'v0.1.3';
+our $VERSION = 'v0.1.4';
 
 use List::Util qw( first any );
 use File::Temp qw( tempfile ); # don't use Path::Tiny to have temp files in error $SHELL
@@ -411,7 +411,7 @@ sub _tokenize {
             }
             die _e({loc=>$loc}, 'bad operation param', $1) if $args =~ /\G(.+)\z/msgc; ## no critic (ProhibitCaptureWithoutTest)
             push @tokens, {
-                loc => $loc,
+                loc => {%{ $loc }},
                 op  => $op,
                 args=> \@args,
                 data=> q{},
@@ -453,7 +453,7 @@ App::migrate - upgrade / downgrade project
 
 =head1 VERSION
 
-This document describes App::migrate version v0.1.3
+This document describes App::migrate version v0.1.4
 
 
 =head1 SYNOPSIS
